summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorPadma, Santhosh Kumar <skpadma@qti.qualcomm.com>2014-03-24 19:30:45 +0530
committerAkash Patel <c_akashp@qca.qualcomm.com>2014-03-25 17:24:41 -0700
commit47cbc961a58c1edb4ab4b726cf09d1eec8b032d1 (patch)
tree350cd83fd99b539a78ab84fd05958c8a51408cf8
parent49a876eec72add35d9290bafc2b76a101143a988 (diff)
qcacld: SME: Send proper TID
Currently, TID is sent wrongly for few commands when addts commands are issued back to back as TID is not getting updated during flow aggregation. This fix ensures to update proper TID from input tspec before issuing addts. Change-Id: I83fd33626ffa6340587bcfad30622b1d85dbea91 CRs-Fixed: 637018
-rw-r--r--CORE/SME/src/QoS/sme_Qos.c3
1 files changed, 2 insertions, 1 deletions
diff --git a/CORE/SME/src/QoS/sme_Qos.c b/CORE/SME/src/QoS/sme_Qos.c
index c5d8ccbcfdfb..c7a9fc9ec8cd 100644
--- a/CORE/SME/src/QoS/sme_Qos.c
+++ b/CORE/SME/src/QoS/sme_Qos.c
@@ -1710,8 +1710,9 @@ sme_QosStatusType sme_QosInternalSetupReq(tpAniSirGlobal pMac,
pSession->readyForPowerSave = VOS_TRUE;
return status;
}
//although aggregating, make sure to request on the correct UP
pACInfo->requested_QoSInfo[tmask - 1].ts_info.up = Tspec_Info.ts_info.up;
+ pACInfo->requested_QoSInfo[tmask - 1].ts_info.tid = Tspec_Info.ts_info.tid;
status = sme_QosSetup(pMac, sessionId,
&pACInfo->requested_QoSInfo[tmask - 1], ac);
VOS_TRACE(VOS_MODULE_ID_SME, VOS_TRACE_LEVEL_INFO_HIGH,
@@ -1710,8 +1710,9 @@ sme_QosStatusType sme_QosInternalSetupReq(tpAniSirGlobal pMac,
return status;
}
- //although aggregating, make sure to request on the correct UP
+ //although aggregating, make sure to request on the correct UP,TID
pACInfo->requested_QoSInfo[tmask - 1].ts_info.up = Tspec_Info.ts_info.up;